package controllers

import (
	"encoding/json"
	"fmt"
	"github.com/beego/beego/v2/server/web"
	"hongze/hongze_api/services"
	"net/http"
	"net/url"
	"strconv"

	"hongze/hongze_api/models"
	"hongze/hongze_api/utils"

	"github.com/rdlucklib/rdluck_tools/log"
)

var apiLog *log.Log

func init() {
	if utils.RunMode == "release" {
		logDir := `/data/rdlucklog/hongze_api`
		apiLog = log.Init("20060102.api", logDir)
	} else {
		apiLog = log.Init("20060102.api")
	}
}

type BaseAuthController struct {
	web.Controller
	User  *models.WxUserItem
	Token string
}

func (this *BaseAuthController) Prepare() {
	fmt.Println("enter prepare")
	method := this.Ctx.Input.Method()
	uri := this.Ctx.Input.URI()
	fmt.Println("Url:", uri)
	if method != "HEAD" {
		if method == "POST" || method == "GET" {
			authorization := this.Ctx.Input.Header("Authorization")
			if authorization == "" {
				cookie := this.Ctx.GetCookie("rddp_access_token")
				utils.FileLog.Info("authorization:%s,cookie:%s", authorization, cookie)
				authorization = cookie
			}
			this.Token = authorization
			if authorization == "" {
				this.JSON(models.BaseResponse{Ret: 408, Msg: "请重新授权！", ErrMsg: "请重新授权:Token is empty or account is empty"}, false, false)
				this.StopRun()
				return
			}
			session, err := models.GetSessionByToken(authorization)
			if err != nil {
				if err.Error() == utils.ErrNoRow() {
					this.JSON(models.BaseResponse{Ret: 408, Msg: "信息已变更,请重新登陆！", ErrMsg: "Token 信息已变更:Token: " + authorization}, false, false)
					this.StopRun()
					return
				}
				this.JSON(models.BaseResponse{Ret: 408, Msg: "网络异常，请稍后重试!", ErrMsg: "获取用户信息异常，Eerr:" + err.Error()}, false, false)
				this.StopRun()
				return
			}
			if session == nil {
				this.JSON(models.BaseResponse{Ret: 408, Msg: "网络异常，请稍后重试!", ErrMsg: "sesson is empty "}, false, false)
				this.StopRun()
				return
			}
			var wxUser *models.WxUserItem
			if session.OpenId != "" {
				tmpWxUser, tmpErr := services.GetWxUserItemByOpenId(session.OpenId)
				wxUser = tmpWxUser
				err = tmpErr
			} else if session.UserId > 0 {
				tmpWxUser, tmpErr := services.GetWxUserItemByUserId(session.UserId, utils.WxPcPlatform)
				wxUser = tmpWxUser
				err = tmpErr
			} else {
				this.JSON(models.BaseResponse{Ret: 408, Msg: "数据异常!", ErrMsg: "sesson is empty "}, false, false)
				this.StopRun()
				return
			}
			//wxUser, err := models.GetWxUserItemByUserId(session.UserId)
			//wxUser, err := services.GetWxUserItemByOpenId(session.OpenId)
			if err != nil {
				//用户openid查询出来发现没有绑定用户
				if err == services.ERR_USER_NOT_BIND {
					this.JSON(models.BaseResponse{Ret: 408, Msg: "信息已变更,请重新登陆！", ErrMsg: "获取admin 信息失败 " + strconv.Itoa(session.UserId)}, false, false)
					//this.StopRun()
					this.User = wxUser
					return
				}
				//没有找到记录
				if err.Error() == utils.ErrNoRow() {
					this.JSON(models.BaseResponse{Ret: 408, Msg: "信息已变更,请重新登陆！", ErrMsg: "获取admin 信息失败 " + strconv.Itoa(session.UserId)}, false, false)
					this.StopRun()
					return
				}
				this.JSON(models.BaseResponse{Ret: 408, Msg: "网络异常，请稍后重试!", ErrMsg: "获取wx_user信息异常，Eerr:" + err.Error()}, false, false)
				this.StopRun()
				return
			}
			if wxUser == nil {
				this.JSON(models.BaseResponse{Ret: 408, Msg: "网络异常，请稍后重试!", ErrMsg: "admin is empty "}, false, false)
				this.StopRun()
				return
			}

			this.User = wxUser
		} else {
			this.JSON(models.BaseResponse{Ret: 408, Msg: "请求异常，请联系客服!", ErrMsg: "POST之外的请求，暂不支持"}, false, false)
			this.StopRun()
			return
		}
	}
}

func (c *BaseAuthController) ServeJSON(encoding ...bool) {
	var (
		hasIndent   = false
		hasEncoding = false
	)
	if web.BConfig.RunMode == web.PROD {
		hasIndent = false
	}
	if len(encoding) > 0 && encoding[0] == true {
		hasEncoding = true
	}
	if c.Data["json"] == nil {
		go utils.SendEmail(utils.APPNAME+" "+utils.RunMode+"异常提醒:", "接口:"+"URI:"+c.Ctx.Input.URI()+";无返回值", utils.EmailSendToUsers)
		return
	}
	baseRes := c.Data["json"].(*models.BaseResponse)
	if baseRes != nil && baseRes.Ret != 200 && baseRes.Ret != 408 && baseRes.IsSendEmail {
		body, _ := json.Marshal(baseRes)
		go utils.SendEmail(utils.APPNAME+" "+utils.RunMode+" 失败提醒", "URI:"+c.Ctx.Input.URI()+"<br/> ErrMsg:"+baseRes.ErrMsg+";<br/>Msg:"+baseRes.Msg+";<br/> Body:"+string(body), utils.EmailSendToUsers)
	}
	c.JSON(c.Data["json"], hasIndent, hasEncoding)
}

func (c *BaseAuthController) JSON(data interface{}, hasIndent bool, coding bool) error {
	c.Ctx.Output.Header("Content-Type", "application/json; charset=utf-8")
	var content []byte
	var err error
	if hasIndent {
		content, err = json.MarshalIndent(data, "", "  ")
	} else {
		content, err = json.Marshal(data)
	}
	if err != nil {
		http.Error(c.Ctx.Output.Context.ResponseWriter, err.Error(), http.StatusInternalServerError)
		return err
	}
	ip := c.Ctx.Input.IP()
	requestBody, _ := url.QueryUnescape(string(c.Ctx.Input.RequestBody))
	apiLog.Println("请求地址：", c.Ctx.Input.URI(), "Authorization:", c.Ctx.Input.Header("Authorization"), "RequestBody：", requestBody, "ResponseBody", string(content), "IP：", ip)
	if coding {
		content = []byte(utils.StringsToJSON(string(content)))
	}

	// 数据加密
	if services.CheckEncryption() {
		content = utils.DesBase64Encrypt(content)
	}
	return c.Ctx.Output.Body(content)
}
