package models

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

// Admin [...]
type Admin struct {
	AdminID                 int64     `gorm:"primaryKey;column:admin_id;type:bigint(20);not null" json:"-"`
	AdminName               string    `gorm:"uniqueIndex:un;index:name;index:admin_pass;column:admin_name;type:varchar(60);not null" json:"adminName"`
	RealName                string    `gorm:"column:real_name;type:varchar(60)" json:"realName"`
	Password                string    `gorm:"index:password;index:admin_pass;column:password;type:varchar(60);not null" json:"password"`
	LastUpdatedPasswordTime time.Time `gorm:"column:last_updated_password_time;type:datetime" json:"lastUpdatedPasswordTime"`
	Enabled                 int8      `gorm:"uniqueIndex:un;column:enabled;type:tinyint(1);not null;default:1" json:"enabled"` // 1:有效，0:禁用
	Email                   string    `gorm:"column:email;type:varchar(60)" json:"email"`
	LastLoginTime           time.Time `gorm:"column:last_login_time;type:datetime" json:"lastLoginTime"`                                         // 最近登陆时间
	CreatedTime             time.Time `gorm:"index:created_time;column:created_time;type:datetime;default:CURRENT_TIMESTAMP" json:"createdTime"` // 创建时间
	LastUpdatedTime         time.Time `gorm:"index:last_updated_time;column:last_updated_time;type:timestamp;not null;default:CURRENT_TIMESTAMP" json:"lastUpdatedTime"`
	Role                    string    `gorm:"column:role;type:varchar(30);default:saller" json:"role"`               // 用户角色
	Mobile                  string    `gorm:"column:mobile;type:varchar(20)" json:"mobile"`                          // 手机号
	RoleType                int8      `gorm:"column:role_type;type:tinyint(4);default:0" json:"roleType"`            // 角色类型:1需要录入指标,0:不需要
	RoleID                  int       `gorm:"column:role_id;type:int(11);default:0" json:"roleId"`                   // 角色id
	RoleName                string    `gorm:"column:role_name;type:varchar(100)" json:"roleName"`                    // 角色名称
	RoleTypeCode            string    `gorm:"column:role_type_code;type:varchar(20);default:''" json:"roleTypeCode"` // 角色编码
	DepartmentID            int       `gorm:"column:department_id;type:int(11);default:0" json:"departmentId"`       // 部门id
	DepartmentName          string    `gorm:"column:department_name;type:varchar(100)" json:"departmentName"`        // 部门名称
	GroupID                 int       `gorm:"column:group_id;type:int(11);default:0" json:"groupId"`                 // 分组id
	GroupName               string    `gorm:"column:group_name;type:varchar(100)" json:"groupName"`                  // 分组名称
	Authority               int8      `gorm:"column:authority;type:tinyint(4);default:0" json:"authority"`           // 管理权限，0：无，1：部门负责人，2：小组负责人,3:超级管理员
	Position                string    `gorm:"column:position;type:varchar(100)" json:"position"`                     // 职位
}

// GetAdminByAdminId 根据admin_id获取系统用户信息
func GetAdminByAdminId(adminId int) (item *Admin, err error) {
	// 第二个返回值是错误对象，在这里略过
	qb, _ := orm.NewQueryBuilder("mysql")

	// 构建查询对象
	qb.Select("real_name",
		"mobile").
		From("admin").
		Where("admin_id =  ? ")

	// 导出 SQL 语句
	sql := qb.String()

	// 执行 SQL 语句
	o := orm.NewOrm()
	err = o.Raw(sql, adminId).QueryRow(&item)
	return
}
