package models

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

// YbApplyRecord 弘则研报客户申请
type YbApplyRecord struct {
	ApplyRecordID   int       `orm:"column(apply_record_id);pk"`
	UserID          int       `orm:"column(user_id)"`
	BusinessCardURL string    `orm:"column(business_card_url)"` // 名片
	RealName        string    `orm:"column(real_name)"`         // 姓名
	CompanyName     string    `orm:"column(company_name)"`      // 客户备注的公司名称
	Mobile          string    `orm:"column(mobile)"`            // 手机号
	Email           string    `orm:"column(email)"`             // 邮箱
	Permission      string    `orm:"column(permission)"`        // 申请权限，多个权限用英文,隔开
	FiccSellerID    uint32    `orm:"column(ficc_seller_id)"`    // ficc销售id，没有开通ficc权限的话，那么所属销售id为0
	SellerName      string    `orm:"column(seller_name)"`       // 销售姓名，多个产品销售用/隔开
	Status          string    `orm:"column(status)"`            // 用户状态，多个产品状态用/隔开
	CompanyIDPay    int       `orm:"column(company_id_pay)"`    // 已付费客户公司id
	CompanyNamePay  string    `orm:"column(company_name_pay)"`  // 已付费客户公司名称
	OpStatus        int       `orm:"column(op_status)"`         // 操作状态，0:未处理,1:已处理
	DealTime        time.Time `orm:"column(deal_time)"`         // 处理时间
	SysUserID       int       `orm:"column(sys_user_id)"`       // 处理人id
	CreateTime      time.Time `orm:"column(create_time)"`       // 创建时间
	IsMove          int       `orm:"column(is_move)"`           // 是否已移动 0-否 1-是
	Source          int       `orm:"column(source)"`            // 申请来源 1-我的 2-活动 3-图库 4-研报
	SourceAgent     int       `orm:"column(source_agent)"`      // 申请入口来源，1：小程序，2：pc
	FromPage        string    `orm:"column(from_page)"`         // 申请来源具体页面
}

type YbApplyReq struct {
	//BusinessCardUrl string `description:"名片地址" json:"business_card_url"`
	CompanyName string `description:"公司名称"`
	RealName    string `description:"用户真实姓名"`
	ReportId    int    `description:报告ID`
	//Permission      string `description:"用户关注品种，多个品种之间用英文,隔开"`
	//Source			int	   `description:"申请来源：1-我的 2-活动 3-图库"`
	//SourceAgent     int    `description:"申请入口来源，1：小程序，2：pc，3：弘则研究公众号"`
	//FromPage        string `description:"申请来源页面"`
}

// GetLastApplyRecordNotOpRecordByUserId 根据用户id获取最近的一条未被操作过的申请记录信息
func GetLastApplyRecordNotOpRecordByUserId(userId int) (item *YbApplyRecord, err error) {
	// 第二个返回值是错误对象，在这里略过
	qb, _ := orm.NewQueryBuilder("mysql")

	// 构建查询对象
	qb.Select("apply_record_id").
		From("yb_apply_record").
		Where("user_id = ? AND op_status = 0")

	// 导出 SQL 语句
	sql := qb.String()

	// 执行 SQL 语句
	o := orm.NewOrm()
	err = o.Raw(sql, userId).QueryRow(&item)
	return
}

// AddYbApplyRecord 新增FICC申请记录
func AddYbApplyRecord(item *YbApplyRecord) (err error) {
	o := orm.NewOrm()
	_, err = o.Insert(item)
	return
}
